from distutils.core import setup

setup(
	name = 'libchaos',
        version = '1.1.0',
	py_modules = ['libchaos'],
	author = 'libchaos',
	author_email = 'libchaos01@163.com',
	url = 'http://github.com/libchaos',
	description = 'a level control of nested list'
     )
